@@ -164,7 +164,13 @@ class Study(skrt.core.Archive):
                                 obj.set_structure_set(ss)
 
                 # Add to list of all objects for this image type
-                all_objs.extend(objs)
+                # The preceding code results in object duplication.
+                # This should be debugged, but for now just avoid
+                # storing duplicates.
+                for obj in objs:
+                    if obj not in all_objs:
+                        all_objs.append(obj)
+                #all_objs.extend(objs)
 
             # Create attribute for objects of this type
             if len(all_objs):
@@ -785,11 +791,29 @@ class Patient(skrt.core.PathData):
                             self.studies.extend(
                                 self.create_objects(dtype=Study, subdir=subdir)
                             )
+        
+        # Add to data objects a reference to the patient object.
+        self.link_study_data_to_patient()
 
         # Record end time, then store initialisation time.
         toc = timeit.default_timer()
         self._init_time = (toc - tic)
 
+    def link_study_data_to_patient(self):
+        '''Add to data objects a reference to the associated patient object.'''
+
+        categories = set()
+
+        for study in self.studies:
+            for attribute in dir(study):
+                if "types" in attribute:
+                    categories.add(attribute)
+            study.patient = self
+
+        for category in categories:
+            for obj in self.combined_objs(category):
+                obj.patient = self
+
     def add_study(self, subdir='', timestamp=None, images=None, 
                   image_type="ct"):
         '''Add a new study.'''
@@ -843,17 +867,51 @@ class Patient(skrt.core.PathData):
         return files
 
     def combined_objs(self, attr):
-        """Get list of all objects of a given attribute <attr> associated
-        with this patient."""
+        '''
+        Get list of objects across all studies associated with
+        this patient.
 
+        **Parameters:**
+
+        attr : str
+            Attribute name, identifying list of objects associated with a study.
+            If attr ends with '_types', then objects of all listed types
+            are retrieved.
+        '''
         all_objs = []
-        for study in self.studies:
-            objs = getattr(study, attr)
-            if objs:
-                all_objs.extend(objs)
+        if attr.endswith('_types'):
+            dtype = attr.replace('_types', 's')
+            for study in self.studies:
+                obj_types = getattr(study, attr, [])
+                for obj_type in sorted(obj_types):
+                    all_objs.extend(getattr(study, f'{obj_type}_{dtype}'))
+        else:
+            for study in self.studies:
+                objs = getattr(study, attr, None)
+                if objs:
+                    all_objs.extend(objs)
         all_objs.sort()
         return all_objs
 
+    def combined_types(self, cls):
+        '''
+        Get list of object types across all studies, for a given class.
+
+        **Parameters:**
+
+        cls : str
+            Class name (case insensitive), for which types of object are
+            to be retrieved.
+        '''
+        all_types = []
+        for study in self.studies:
+            obj_types = getattr(study, f'{cls.lower()}_types', [])
+            for obj_type in sorted(obj_types):
+                if not obj_type in all_types:
+                    all_types.append(obj_type)
+        all_types.sort()
+        return all_types
+
     def load_demographics(self):
         """Load a patient's birth date, age, and sex."""
 
@@ -886,7 +944,10 @@ class Patient(skrt.core.PathData):
 
         # Obtain birth date as pandas Timestamp.
         if info["BirthDate"]:
-            info["BirthDate"] = pd.Timestamp(info["BirthDate"])
+            try:
+                info["BirthDate"] = pd.Timestamp(info["BirthDate"])
+            except ValueError:
+                info["BirthDate"] = None
 
         # Obtain age as an integer in years.
         if info["Age"]:
@@ -915,8 +976,9 @@ class Patient(skrt.core.PathData):
             self.load_demographics()
         return self.birth_date
 
-    def get_info(self, collections=None, data_labels=None, plan_image_type='ct',
-            treatment_image_type='mvct', min_delta=4, unit='hour', df=False):
+    def get_info(self, collections=None, data_labels=None, image_types=None,
+            plan_image_type=None, treatment_image_type=None,
+            min_delta=4, unit='hour', df=False):
         '''
         Retrieve patient summary information.
 
@@ -931,14 +993,20 @@ class Patient(skrt.core.PathData):
             in data paths.  If None, an empty dictionary is used.
 
         data_labels : list, default=None
-            List of strings specifying types of data associated with
+            List of strings specifying labels of data associated with
             a study.  If None, the list used is:
             ['image', 'structure_set', 'dose', 'plan'].
 
-        plan_image_type : str, default='ct'
+        image_types : list, default=None
+            List of strings indicating types of image for which information
+            is to be retrieved, for example ['ct', 'mr'].  If None,
+            information is retrieved for all image types in the patient
+            dataset.  Ignored if 'image' isn't included in data_labels.
+
+        plan_image_type : str, default=None
             String identifying type of image recorded for treatment planning.
 
-        treatment_image_type : str, default='mvct'
+        treatment_image_type : str, default=None
             String identifying type of image recorded at treatment time.
 
         min_delta : int/pandas.Timedelta, default=4
@@ -963,12 +1031,15 @@ class Patient(skrt.core.PathData):
         if data_labels is None:
             data_labels = ['image', 'structure_set', 'dose', 'plan']
 
+        # Ensure that list is defined for image_types.
+        if image_types is None:
+            image_types = self.combined_types('image')
+
         # Create dictionary for information to be returned.
         info = {}
 
         # Store basic patient information.
         info['id'] = self.id
-        info['disease'] = self.id.split("_")[1]
         info['birth_date'] = self.get_birth_date()
         info['age'] = self.get_age()
         info['sex'] = self.get_sex()
@@ -986,6 +1057,8 @@ class Patient(skrt.core.PathData):
         # Information is taken from the earliest plan file,
         # in the earliest study containing a plan file.
         info['plan_name'] = None
+        info['plan_description'] = None
+        info['plan_prescription_description'] = None
         info['plan_fraction'] = None
         info['plan_target_dose'] = None
         for study in self.studies:
@@ -994,6 +1067,9 @@ class Patient(skrt.core.PathData):
                 plan = study.plan_types[plan_type][0]
                 plan.load()
                 info['plan_name'] = plan.name
+                info['plan_description'] = plan.description
+                info['plan_prescription_description'] = (
+                        plan.prescription_description)
                 info['plan_fraction'] = plan.n_fraction
                 info['plan_target_dose'] = plan.target_dose
                 break
@@ -1010,10 +1086,15 @@ class Patient(skrt.core.PathData):
                     # - combined size (in bytes) of all files;
                     # For image data, also store information on:
                     # - number of image objects.
+                    # For dose data, also store information on:
+                    # - maximum dose.
                     for data_type, objs in sorted(data_types.items()):
+                        if data_type not in image_types:
+                            continue
                         file_label = f'{data_label}_{data_type}_file'
                         size_label = f'{data_label}_{data_type}_size'
                         obj_label = f'{data_label}_{data_type}_obj'
+                        dose_label = f'{data_label}_{data_type}_max'
                         if not file_label in info:
                             info[file_label] = 0
                         if not size_label in info:
@@ -1022,13 +1103,26 @@ class Patient(skrt.core.PathData):
                             if obj_label not in info:
                                 info[obj_label] = 0
                             info[obj_label] += len(objs)
+                        if 'dose' == data_label:
+                            if dose_label not in info:
+                                info[dose_label] = 0
+                            for obj in objs:
+                               info[dose_label] = max(
+                                       info[dose_label], obj.get_max())
                         for obj in objs:
                             info[file_label] += obj.get_n_file()
                             info[size_label] += obj.get_file_size()
 
         # Create lists of image objects for planning and for treatment.
-        plan_images = self.combined_objs(f'{plan_image_type}_images')
-        treatment_images = self.combined_objs(f'{treatment_image_type}_images')
+        if plan_image_type:
+            plan_images = self.combined_objs(f'{plan_image_type}_images')
+        else:
+            plan_images = None
+        if treatment_image_type:
+            treatment_images = self.combined_objs(
+                    f'{treatment_image_type}_images')
+        else:
+            treatment_images = None
 
         # Store time of image used for plan creation.
         if plan_images:
@@ -1088,13 +1182,10 @@ class Patient(skrt.core.PathData):
             If False, return summary information as a dictionary.
             If True, return summary information as a pandas dataframe.
         '''
+
+        # Ensure that list is defined for image_types.
         if image_types is None:
-            all_image_types = self.combined_objs('image_types')
-            image_types = []
-            for image_types_now in all_image_types:
-                for image_type in image_types_now:
-                    if image_type not in image_types:
-                        image_types.append(image_type)
+            image_types = self.combined_types('image')
 
         all_info = []
         for image_type in sorted(image_types):
@@ -1120,6 +1211,113 @@ class Patient(skrt.core.PathData):
 
         return (pd.DataFrame(all_info) if df else all_info)
 
+    def get_dose_info(self, dose_types=None, df=False):
+        '''
+        Retrieve information about dose.
+
+        **Parameters:**
+
+        dose_types : list, default=None
+            List of strings indicating types of dose for which information
+            is to be retrieved.  If None, information is retrieved for
+            all dose types in the patient dataset.
+
+        df : bool, default=False
+            If False, return summary information as a dictionary.
+            If True, return summary information as a pandas dataframe.
+        '''
+
+        # Ensure that list is defined for dose_types.
+        if dose_types is None:
+            dose_types = self.combined_types('dose')
+
+        all_info = []
+        for dose_type in sorted(dose_types):
+            dose_label = f'{dose_type.lower()}_doses'
+            doses = self.combined_objs(dose_label)
+            for dose in sorted(doses):
+                dose.load()
+                info = {}
+                info['id'] = self.id
+                info['timestamp'] = dose.get_pandas_timestamp()
+                info['day'] = (info['timestamp'].isoweekday()
+                        if info['timestamp'] else None)
+                info['dose_summation_type'] = dose.get_dose_summation_type()
+                info['dose_max'] = dose.get_max()
+                info['dose_units'] = dose.get_dose_units()
+                info['dose_type'] = dose.get_dose_type()
+                info['linked_plan'] = hasattr(dose, 'plan')
+                if hasattr(dose, 'plan'):
+                    info['linked_plan_status'] = dose.plan.get_approval_status()
+                    info['linked_plan_fraction'] = dose.plan.get_n_fraction()
+                else:
+                    info['linked_plan_status'] = None
+                    info['linked_plan_fraction'] = None
+                all_info.append(info)
+
+        return (pd.DataFrame(all_info) if df else all_info)
+
+    def get_plan_info(self, plan_types=None, df=False):
+        '''
+        Retrieve information about treatment plans.
+
+        **Parameters:**
+
+        plan_types : list, default=None
+            List of strings indicating types of plan for which information
+            is to be retrieved.  If None, information is retrieved for
+            all plan types in the patient dataset.
+
+        df : bool, default=False
+            If False, return summary information as a dictionary.
+            If True, return summary information as a pandas dataframe.
+        '''
+
+        # Ensure that list is defined for plan_types.
+        if plan_types is None:
+            plan_types = self.combined_types('plan')
+
+        all_info = []
+        for plan_type in sorted(plan_types):
+            plan_label = f'{plan_type.lower()}_plans'
+            plans = self.combined_objs(plan_label)
+            for plan in sorted(plans):
+                plan.load()
+                info = {}
+                info['id'] = self.id
+                info['timestamp'] = plan.get_pandas_timestamp()
+                info['day'] = (info['timestamp'].isoweekday()
+                        if info['timestamp'] else None)
+                info['plan_type'] = plan_type
+                info['plan_name'] = plan.get_name()
+                info['plan_description'] = plan.get_description()
+                info['plan_prescription_description'] = (
+                        plan.get_prescription_description())
+                info['plan_fraction'] = plan.get_n_fraction()
+                info['plan_target_dose'] = plan.get_target_dose()
+                info['plan_status'] = plan.get_approval_status()
+                info['linked_doses'] = len(plan.doses)
+
+                dose_summation_types = []
+                max_doses = []
+                for dose in plan.doses:
+                    dose_summation_types.append(dose.get_dose_summation_type())
+                    max_doses.append(dose.get_max())
+                info['linked_dose_summation_type'] = (
+                        '_'.join(dose_summation_types))
+                if not max_doses:
+                    info['linked_dose_max'] = None
+                elif len(max_doses) == 1:
+                    info['linked_dose_max'] = max_doses[0]
+                else:
+                    max_doses = [f'{max_dose:.4f}'
+                            for max_dose in max_doses]
+                    info['linked_dose_max'] = '_'.join(max_doses)
+
+                all_info.append(info)
+
+        return (pd.DataFrame(all_info) if df else all_info)
+
     def get_subdir_studies(self, subdir=""):
         """Get list of studies within a given subdirectory."""
 
